
library("effsize")

# data analysis for methods having different size

small_set <- read.csv("/Users/fabiopalomba/Documents/PhD/Papers/Submitted/ICSE17-impact-on-energy-consumption/data-analysis/additional-analysis/size/small.csv", 
                       sep = ";", header = FALSE, stringsAsFactors=FALSE)

medium_set <- read.csv("/Users/fabiopalomba/Documents/PhD/Papers/Submitted/ICSE17-impact-on-energy-consumption/data-analysis/additional-analysis/size/medium.csv", 
                           header = FALSE, stringsAsFactors=FALSE)

large_set <- read.csv("/Users/fabiopalomba/Documents/PhD/Papers/Submitted/ICSE17-impact-on-energy-consumption/data-analysis/additional-analysis/size/large.csv", 
                       header = FALSE, stringsAsFactors=FALSE)

small_data <- rapply(small_set, c)
medium_data <- rapply(medium_set, c)
large_data <- rapply(large_set, c)

cor(small_data$energyConsumption, correlation_data$isSmells, method="spearman")

boxplot(small_data, medium_data, large_data, horizontal = TRUE, pars=list(boxwex=.5), 
        col = c("grey", "grey", "grey"), names = c("small\nmethods","medium\nmethods","large\nmethods"))

print(summary(small_data))
print(summary(medium_data))
print(summary(large_data))

wilcox.test(small_data, medium_data, alternative = c("greater"))
wilcox.test(medium_data, large_data, alternative = c("greater"))
wilcox.test(small_data, large_data, alternative = c("greater"))

cliff.delta(small_data, medium_data)
cliff.delta(medium_data, large_data)
cliff.delta(small_data, large_data)

# data analysis for methods having different complexity

low_complexity_set <- read.csv("/Users/fabiopalomba/Documents/PhD/Papers/Working/Antipatterns/impact-on-energy-consumption/additional-analysis/complexity/low.csv", 
                      sep = ";", header = FALSE, stringsAsFactors=FALSE)

medium_complexity_set <- read.csv("/Users/fabiopalomba/Documents/PhD/Papers/Working/Antipatterns/impact-on-energy-consumption/additional-analysis/complexity/medium.csv", 
                       header = FALSE, stringsAsFactors=FALSE)

high_complexity_set <- read.csv("/Users/fabiopalomba/Documents/PhD/Papers/Working/Antipatterns/impact-on-energy-consumption/additional-analysis/complexity/high.csv", 
                      header = FALSE, stringsAsFactors=FALSE)

low_complexity_data <- rapply(low_complexity_set, c)
medium_complexity_data <- rapply(medium_complexity_set, c)
high_complexity_data <- rapply(high_complexity_set, c)

boxplot(low_complexity_data, medium_complexity_data, high_complexity_data, horizontal = TRUE, pars=list(boxwex=.5), 
        col = c("grey", "grey", "grey"), names = c("low-compl.\nmethods","medium-compl.\nmethods","high-compl.\nmethods"))

print(summary(low_complexity_data))
print(summary(medium_complexity_data))
print(summary(high_complexity_data))

wilcox.test(low_complexity_data, medium_complexity_data, alternative = c("greater"))
wilcox.test(medium_complexity_data, high_complexity_data, alternative = c("greater"))
wilcox.test(low_complexity_data, high_complexity_data, alternative = c("greater"))

cliff.delta(low_complexity_data, medium_complexity_data)
cliff.delta(medium_complexity_data, high_complexity_data)
cliff.delta(low_complexity_data, high_complexity_data)

# data analysis for methods having different coverage

low_coverage_set <- read.csv("/Users/fabiopalomba/Documents/PhD/Papers/Working/Antipatterns/impact-on-energy-consumption/additional-analysis/coverage/low.csv", 
                               sep = ";", header = FALSE, stringsAsFactors=FALSE)

medium_coverage_set <- read.csv("/Users/fabiopalomba/Documents/PhD/Papers/Working/Antipatterns/impact-on-energy-consumption/additional-analysis/coverage/medium.csv", 
                                  header = FALSE, stringsAsFactors=FALSE)

high_coverage_set <- read.csv("/Users/fabiopalomba/Documents/PhD/Papers/Working/Antipatterns/impact-on-energy-consumption/additional-analysis/coverage/high.csv", 
                                header = FALSE, stringsAsFactors=FALSE)

low_coverage_data <- rapply(low_coverage_set, c)
medium_coverage_data <- rapply(medium_coverage_set, c)
high_coverage_data <- rapply(high_coverage_set, c)

boxplot(low_coverage_data, medium_coverage_data, high_coverage_data, horizontal = TRUE, pars=list(boxwex=.5), 
        col = c("grey", "grey", "grey"), names = c("low-coverage.\nmethods","medium-coverage\nmethods","high-coverage\nmethods"))

print(summary(low_coverage_data))
print(summary(medium_coverage_data))
print(summary(high_coverage_data))

wilcox.test(low_coverage_data, medium_coverage_data, alternative = c("greater"))
wilcox.test(medium_coverage_data, high_coverage_data, alternative = c("greater"))
wilcox.test(low_coverage_data, high_coverage_data, alternative = c("greater"))

cliff.delta(low_coverage_data, medium_coverage_data)
cliff.delta(medium_coverage_data, high_coverage_data)
cliff.delta(low_coverage_data, high_coverage_data)

# data analysis for smelly and non-smelly methods computed by using the sum of the energy 
# consumed by such methods, rather than the mean

smelly_set <- read.csv("/Users/fabiopalomba/Documents/PhD/Papers/Working/Antipatterns/impact-on-energy-consumption/online-appendix/dataset/additional-analysis/petra-sum/smellyDistribution.csv", 
                       sep = ";", header = FALSE, stringsAsFactors=FALSE)

non_smelly_set <- read.csv("/Users/fabiopalomba/Documents/PhD/Papers/Working/Antipatterns/impact-on-energy-consumption/online-appendix/dataset/additional-analysis/petra-sum/nonSmellyDistribution.csv", 
                           header = FALSE, stringsAsFactors=FALSE)

smelly_data <- rapply(as.list(smelly_set$V1), c)
non_smelly_data <- rapply(non_smelly_set, c)

boxplot(smelly_data, non_smelly_data, horizontal = TRUE, pars=list(boxwex=.5), 
        col = c("grey", "grey"), names = c("smelly\nmethods","non-smelly\nmethods"))

print(summary(smelly_data))
print(summary(non_smelly_data))

wilcox.test(smelly_data, non_smelly_data, alternative = c("greater"))
cliff.delta(smelly_data, non_smelly_data)